@@ -36,7 +36,7 @@ use Digest::MD5 ();
 use Scalar::Util ();
 
 use vars qw( $VERSION );
-$VERSION = q(0.981);
+$VERSION = q(0.982);
 
 ##
 # Set to 4 and 'N' for 32-bit offset tags (default).  Theoretical limit of 4 GB per file.
@@ -102,7 +102,6 @@ sub SIG_SIZE   () {  1  }
 ##
 sub TYPE_HASH   () { SIG_HASH   }
 sub TYPE_ARRAY  () { SIG_ARRAY  }
-sub TYPE_SCALAR () { SIG_SCALAR }
 
 sub _get_args {
     my $proto = shift;
@@ -209,26 +208,13 @@ sub _open {
 
 	if (defined($self->_fh)) { $self->_close(); }
 	
-    eval {
-        local $SIG{'__DIE__'};
-        # Theoretically, adding O_BINARY should remove the need for the binmode
-        # Of course, testing it is going to be ... interesting.
-        my $flags = O_RDWR | O_CREAT | O_BINARY;
+    my $flags = O_RDWR | O_CREAT | O_BINARY;
 
-        my $fh;
-        sysopen( $fh, $self->_root->{file}, $flags )
-            or $fh = undef;
-        $self->_root->{fh} = $fh;
-    }; if ($@ ) { $self->_throw_error( "Received error: $@\n" ); }
-	if (! defined($self->_fh)) {
-		return $self->_throw_error("Cannot sysopen file: " . $self->_root->{file} . ": $!");
-	}
+    my $fh;
+    sysopen( $fh, $self->_root->{file}, $flags )
+		or $self->_throw_error( "Cannot sysopen file: " . $self->_root->{file} . ": $!" );
 
-    my $fh = $self->_fh;
-
-    #XXX Can we remove this by using the right sysopen() flags?
-    # Maybe ... q.v. above
-    binmode $fh; # for win32
+    $self->_root->{fh} = $fh;
 
     if ($self->_root->{autoflush}) {
         my $old = select $fh;
@@ -1327,7 +1313,7 @@ sub STORE {
 		return;
 	}
 
-    unless ( _is_writable( $self->_fh ) ) {
+    if ( $^O ne 'MSWin32' && !_is_writable( $self->_fh ) ) {
         $self->_throw_error( 'Cannot write to a readonly filehandle' );
     }
 	
